#include "baseobjectbuilder.h"
#include "constants.h"
#include "objects/object.h"
#include "parsers/objectparserinterface.h"

#include <qdebug.h>

namespace ao_builder
{
bool BaseObjectBuilder::buildFieldWithLocale(ObjectParserInterface *parser,
                                             QString sectionName,
                                             QString entryName,
                                             QString &field,
                                             QMap<QString, QString> &localeStorage)
{
    auto sections = parser->getSections();

    auto alteratorEntrySectionIt = sections.find(sectionName);
    if (alteratorEntrySectionIt == sections.end())
    {
        return false;
    }

    auto section = *alteratorEntrySectionIt;

    QList<ObjectParserInterface::IniField> listOfKeys = section.values(entryName);

    QString defaultName = parser->getDefaultValue(listOfKeys);

    if (defaultName.isEmpty())
    {
        return false;
    }

    field = defaultName;

    for (const ObjectParserInterface::IniField &currentIniFileKey : listOfKeys)
    {
        localeStorage.insert(currentIniFileKey.keyLocale, currentIniFileKey.value.toString());
    }

    return true;
}

// Build common fields
bool BaseObjectBuilder::buildBase(ObjectParserInterface *parser, QString sectionName, Object *object)
{
    QString type = parser->getValue(sectionName, ALTERATOR_ENTRY_TYPE_KEY_NAME);
    if (type.isEmpty())
    {
        return false;
    }
    object->m_type = type;

    QString name = parser->getValue(sectionName, ALTERATOR_ENTRY_OBJECT_KEY_NAME);
    if (name.isEmpty())
    {
        return false;
    }
    object->m_name = name;

    auto weights = parseValuesFromKey(parser, sectionName, OBJECT_WEIGHT_KEY_NAME, ";");
    if (!weights.empty())
    {
        bool ok    = true;
        int weight = weights[0].toInt(&ok);
        if (ok)
        {
            object->m_weight = weight;
        }
        else
        {
            qWarning() << "Cannot parse" << OBJECT_WEIGHT_KEY_NAME << "of object" << object->m_name << "using default";
            object->m_weight = DEFAULT_WEIGHT;
        }
    }
    else
    {
        qInfo() << OBJECT_WEIGHT_KEY_NAME << "of object" << object->m_name << "is not specified, using default";
        object->m_weight = DEFAULT_WEIGHT;
    }

    return true;
}

std::vector<QString> BaseObjectBuilder::parseValuesFromKey(ObjectParserInterface *parser,
                                                           QString section,
                                                           QString key,
                                                           QString delimiter)
{
    QString values = parser->getValue(section, key);
    if (values.isEmpty())
    {
        return {};
    }

    if (values.back() == delimiter)
    {
        values.truncate(values.size() - 1);
    }

    QStringList valuesList = values.split(delimiter);

    std::vector<QString> result;
    for (QString &currentValue : valuesList)
    {
        if (!currentValue.isEmpty())
        {
            result.push_back(currentValue);
        }
    }

    return result;
}

} // namespace ao_builder
