#include "legacyobjectbuilder.h"
#include "../objects/legacyobject.h"
#include "constants.h"
#include <memory>

namespace ao_builder
{
std::unique_ptr<Object> LegacyObjectBuilder::buildObject(ObjectParserInterface *parser)
{
    auto result = std::make_unique<LegacyObject>();

    if (!buildBase(parser, DESKTOP_ENTRY_SECTION_NAME, result.get()))
    {
        return nullptr;
    }

    if (!buildFieldWithLocale(parser,
                              DESKTOP_ENTRY_SECTION_NAME,
                              DESKTOP_ENTRY_OBJECT_KEY_NAME,
                              result->m_displayName,
                              result->m_displayNameLocaleStorage))
    {
        return nullptr;
    }

    QString categoryId   = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_CATEGORY_KEY_NAME);
    result->m_categoryId = categoryId;

    QString icon   = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_ICON_KEY_NAME);
    result->m_icon = icon;

    QString x_Alterator_URI   = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_X_ALTERATOR_URI_KEY_NAME);
    result->m_x_Alterator_URI = x_Alterator_URI;

    QString x_Alterator_Weight = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_X_ALTERATOR_WEIGHT_KEY_NAME);
    result->m_x_Alterator_Weight = x_Alterator_Weight;

    QString x_Alterator_Help   = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_X_ALTERATOR_HELP_KEY_NAME);
    result->m_x_Alterator_Help = x_Alterator_Help;

    QString x_Alterator_UI   = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_X_ALTERATOR_UI_KEY_NAME);
    result->m_x_Alterator_UI = x_Alterator_UI;

    QString terminal = parser->getValue(DESKTOP_ENTRY_SECTION_NAME, LEGACY_OBJECT_TERMINAL_KEY_NAME);
    if (terminal.toLower() == QString("true"))
    {
        result->m_isTerminal = true;
    }

    QString x_Alterator_Internal_Name = parser->getValue(DESKTOP_ENTRY_SECTION_NAME,
                                                         LEGACY_OBJECT_X_ALTERATOR_INTERNAL_KEY_NAME);

    result->m_x_Alterator_Internal_Name = x_Alterator_Internal_Name;

    result->m_isLegacy = true;

    return result;
}
} // namespace ao_builder
